import {NamedNode} from 'lincd/models';
import {JSONLD} from 'lincd-jsonld/utils/JSONLD';
import {createNameSpace} from 'lincd/utils/NameSpace';
import {linkedOntology} from '../package.js';
import * as _this from './dcmitype.js';

export var loadData = () => {
  if (typeof module !== 'undefined' && typeof exports !== 'undefined') {
    // CommonJS import
    return import('../data/dcmitype.json').then((data) => JSONLD.parse(data));
  } else {
    // ESM import
    //@ts-ignore
    return import('../data/dcmitype.json', {assert: {type: 'json'}}).then(
      (data) => JSONLD.parse(data.default),
    );
  }
};

export var ns = createNameSpace('http://purl.org/dc/dcmitype/');

export var _self: NamedNode = ns('');

export var Collection: NamedNode = ns('Collection');
export var Dataset: NamedNode = ns('Dataset');
export var Event: NamedNode = ns('Event');
export var Image: NamedNode = ns('Image');
export var InteractiveResource: NamedNode = ns('InteractiveResource');
export var MovingImage: NamedNode = ns('MovingImage');
export var PhysicalObject: NamedNode = ns('PhysicalObject');
export var Service: NamedNode = ns('Service');
export var Software: NamedNode = ns('Software');
export var Sound: NamedNode = ns('Sound');
export var StillImage: NamedNode = ns('StillImage');
export var Text: NamedNode = ns('Text');

export const dcmitype = {
  Collection,
  Dataset,
  Event,
  Image,
  InteractiveResource,
  MovingImage,
  PhysicalObject,
  Service,
  Software,
  Sound,
  StillImage,
  Text,
};

linkedOntology(_this, ns, 'dcmitype', loadData, '../data/dcelems.json'); // RDF seems to use 'dc' as the prefix
